import React from 'react';
import { ReactWidget } from '@jupyterlab/apputils';
import { ISignal, Signal } from '@lumino/signaling';
import DatasourceView from './DatasourceView';
import DatasyncView from './DatasyncView';
import DataView from './DataView';
import { IDatasource } from './api/datasource';
import { Widget } from '@lumino/widgets';

interface ITableOpenSignalData {
  datasource: IDatasource;
  tableName: string;
}

class DataViewWidget extends ReactWidget {
  constructor(manager: string, options?: Widget.IOptions) {
    super(options);
    this._manager = manager;
  }

  public get tableOpened(): ISignal<DataViewWidget, ITableOpenSignalData> {
    return this._tableOpened;
  }

  render(): JSX.Element {
    const datasourceView = (
      <DatasourceView
        manager={this._manager}
        onOpenTable={(datasource, tableName) =>
          this._tableOpened.emit({ datasource, tableName })
        }
      />
    );

    const datasyncView = <DatasyncView />;

    return (
      <div
        style={{
          height: '100%',
          display: 'flex',
          flexDirection: 'column'
        }}
      >
        <DataView
          dataSourceElement={datasourceView}
          dataSyncElement={datasyncView}
        />
      </div>
    );
  }

  private _manager: string;
  private _tableOpened = new Signal<DataViewWidget, ITableOpenSignalData>(this);
}

export default DataViewWidget;
